@@ -25,7 +25,7 @@ let files = ref []
 let ocamldep = ref "ocamldep"
 
 let add_file file =
-  files := file :: !files
+  files := Filename.basename file :: !files
 
 let usage = 
   "Usage: ocamldsort [-I <dir>] [-pp <command>] [-d <command>] <files>"
